@@ -1,5 +1,6 @@
 import os
 import os.path as osp
+import logging
 
 import connexion
 from flask_sqlalchemy import SQLAlchemy  # TODO: remove
@@ -8,6 +9,8 @@ from flask_cors import CORS
 
 from .util import rand_string
 
+log = logging.getLogger("PaddleLabel")
+
 basedir = os.path.abspath(os.path.dirname(__file__))
 
 db_path = f"{osp.join(os.path.expanduser('~'), '.paddlelabel', 'paddlelabel.db')}"
@@ -15,14 +18,15 @@ db_path = f"{osp.join(os.path.expanduser('~'), '.paddlelabel', 'paddlelabel.db')
 if not osp.exists(osp.dirname(db_path)):
     os.makedirs(osp.dirname(db_path))
 sqlite_url = f"sqlite:///{db_path}"
-print("database url: ", sqlite_url)
+print(f"Database url: {sqlite_url}")
 
-connexion_app = connexion.App(__name__)
+connexion_app = connexion.App("PaddleLabel")
 app = connexion_app.app
 app.config["SQLALCHEMY_DATABASE_URI"] = sqlite_url
 app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
 app.config["SQLALCHEMY_ECHO"] = False
 app.config["SECRET_KEY"] = rand_string(30)
+
 app.static_url_path = "/static"
 app.static_folder = osp.join(basedir, "static")
 CORS(connexion_app.app)
