@@ -22,6 +22,86 @@ from paddlelabel.api.rpc.seg import polygon2points
 # import matplotlib.pyplot as plt
 
 
+def draw_mask(data, mask_type="pesudo"):
+    height, width = map(int, data.size.split(",")[1:3])
+    if mask_type == "pesudo":
+        mask = np.zeros((height, width, 3))
+    else:
+        mask = np.zeros((height, width))
+
+    for ann in data.annotations:
+        if ann.type not in ["brush", "polygon", "points", "rubber"]:
+            continue
+
+        # # TODO: patch. some eiseg result remove
+        # if ann.result[:2] == "[[":
+        #     continue
+
+        label_id = ann.label.label_id
+        result = ann.result.strip().split(",")
+
+        # TODO: path, remove this. frontend eiseg returns result that are 0,0,
+        # ===
+        result = [r for r in result if r != ""]
+        if len(result) == 2:
+            continue
+        # ===
+        
+        try:
+            result = [int(float(p)) for p in result]
+        except:
+            print(ann)
+            print(result, "to float error, plz open an issue for this")
+
+        # TODO: patch. [0,0,...] means points. to be changed
+        print("======")
+        print(result[0:2])
+        if result[0] == 0 and result[1] == 0:
+            ann.type = "points"
+            print("in")
+        print(ann.type)
+        print("=====")
+
+        # TODO: patch. [not 0, 0] means brush. to be changed
+        if result[0] != 0 and result[1] == 0:
+            ann.type = "rubber"
+
+        if mask_type == "pesudo":
+            color = [0, 0, 0] if ann.type == "rubber" else hex_to_rgb(ann.label.color)[::-1]
+        else:
+            color = 0 if ann.type == "rubber" else int(label_id)
+
+        
+        if ann.type in ["brush", "rubber"]:
+            points = result[2:]
+            line_width = result[0]
+            if line_width == 0:
+                print(ann, "!!!!! point/rubber type but width 0, open an issue!")
+                line_width = 1
+            prev_w, prev_h = points[0:2]
+            try:
+                for idx in range(2, len(points), 2):
+                    w, h = points[idx : idx + 2]
+                    cv2.line(mask, (prev_w, prev_h), (w, h), color, line_width)
+                    prev_w, prev_h = w, h
+            except Exception as e:
+                abort(detail=e.msg, status=500, title="cv2 error")
+        else:
+            if ann.type == "points":
+                points = result[2:]
+            elif ann.type == "polygon":
+                for idx in range(0, len(result), 2):
+                    result[idx] = int(result[idx] + width / 2)
+                    result[idx + 1] = int(result[idx + 1] + height / 2)
+                points = polygon2points(result)
+                points = np.array(points).reshape((-1))
+            
+            for idx in range(0, len(points), 2):
+                mask[points[idx+1]][points[idx]] = color
+
+    return mask
+
+
 def parse_semantic_mask(annotation_path, labels):
     ann = cv2.imread(annotation_path, cv2.IMREAD_UNCHANGED)
     frontend_id = 1
@@ -48,13 +128,13 @@ def parse_semantic_mask(annotation_path, labels):
 
     for label in labels:
         label_mask = deepcopy(ann)
-        label_mask[label_mask != label.id] = 0
+        label_mask[label_mask != label.label_id] = 0
         label_mask[label_mask != 0] = 255
 
         if label_mask.sum() == 0:
             continue
 
-        ann[ann == label.id] = 0
+        ann[ann == label.label_id] = 0
         (cc_num, cc_mask, values, centroid) = cv2.connectedComponentsWithStats(label_mask, connectivity=8)
         for cc_id in range(1, cc_num):
             h, w = np.where(cc_mask == cc_id)
@@ -65,7 +145,7 @@ def parse_semantic_mask(annotation_path, labels):
                     "label_name": label.name,
                     "result": result,
                     "type": "brush",
-                    "frontend_id": label.id,
+                    "frontend_id": label.label_id,
                 }
             )
             frontend_id += 1
@@ -109,8 +189,8 @@ def parse_instance_mask(annotation_path, labels):
 
 
 class InstanceSegmentation(BaseTask):
-    def __init__(self, project, data_dir=None):
-        super().__init__(project, skip_label_import=True, data_dir=data_dir)
+    def __init__(self, project, data_dir=None, is_export=False):
+        super().__init__(project, skip_label_import=True, data_dir=data_dir, is_export=is_export)
         self.importers = {
             "mask": self.mask_importer,
             "polygon": self.coco_importer,
@@ -130,9 +210,7 @@ class InstanceSegmentation(BaseTask):
         # 1. set params
         project = self.project
         if data_dir is None:
-            base_dir = project.data_dir
-            data_dir = osp.join(base_dir, "JPEGImages")
-            ann_dir = osp.join(base_dir, "Annotations")
+            data_dir = project.data_dir
 
         background_line = self.import_labels(ignore_first=True)
         other_settings = project._get_other_settings()
@@ -141,7 +219,7 @@ class InstanceSegmentation(BaseTask):
 
         ann_dict = {
             osp.basename(p).split(".")[0]: p
-            for p in listdir(ann_dir, {"exclude_prefix": ["."], "include_postfix": [".tiff", ".tif"]})
+            for p in listdir(data_dir, {"exclude_prefix": ["."], "include_postfix": [".tiff", ".tif"]})
         }
 
         # 2. import records
@@ -149,7 +227,7 @@ class InstanceSegmentation(BaseTask):
             id = osp.basename(data_path).split(".")[0]
             data_path = osp.join(data_dir, data_path)
             if id in ann_dict.keys():
-                ann_path = osp.join(ann_dir, ann_dict[id])
+                ann_path = osp.join(data_dir, ann_dict[id])
                 size, anns = parse_instance_mask(ann_path, project.labels)
             else:
                 anns = []
@@ -202,6 +280,9 @@ class InstanceSegmentation(BaseTask):
                 if ann.type == "brush":
                     points = result[2:]
                     line_width = result[0]
+                    if result[1] == 0:
+                        frontend_id = 0
+                        label_id = 0
                     prev_w, prev_h = points[0:2]
                 else:
                     for idx in range(0, len(result), 2):
@@ -216,6 +297,7 @@ class InstanceSegmentation(BaseTask):
                         w, h = points[idx : idx + 2]
                         if line_width == 0:
                             line_width = 1
+
                         cv2.line(
                             label_mask,
                             (prev_w, prev_h),
@@ -274,7 +356,6 @@ class InstanceSegmentation(BaseTask):
             # 1. create all labels
             self.create_coco_labels(coco.cats.values())
 
-            print("=====", data_paths)
             ann_by_task = {}
             # 2. get image full path and size
             for idx, img in coco.imgs.items():
@@ -429,8 +510,8 @@ class InstanceSegmentation(BaseTask):
 
 
 class SemanticSegmentation(InstanceSegmentation):
-    def __init__(self, project, data_dir=None):
-        super().__init__(project, data_dir=data_dir)
+    def __init__(self, project, data_dir=None, is_export=False):
+        super().__init__(project, data_dir=data_dir, is_export=is_export)
         self.importers = {
             "mask": self.mask_importer,
             "polygon": self.coco_importer,
@@ -452,8 +533,10 @@ class SemanticSegmentation(InstanceSegmentation):
         project = self.project
         if data_dir is None:
             base_dir = project.data_dir
-            data_dir = osp.join(base_dir, "JPEGImages")
-            ann_dir = osp.join(base_dir, "Annotations")
+        else:
+            base_dir = data_dir
+        data_dir = osp.join(base_dir, "JPEGImages")
+        ann_dir = osp.join(base_dir, "Annotations")
 
         background_line = self.import_labels(ignore_first=True)
         other_settings = project._get_other_settings()
@@ -469,25 +552,28 @@ class SemanticSegmentation(InstanceSegmentation):
             if id in ann_dict.keys():
                 ann_path = osp.join(ann_dir, ann_dict[id])
                 size, anns = parse_semantic_mask(ann_path, project.labels)
+                print("size", size)
             else:
                 anns = []
                 img = cv2.imread(data_path)
                 s = [1] + list(img.shape)
+                print(s)
                 size = ",".join([str(s) for s in s])
 
             self.add_task([{"path": data_path, "size": size}], [anns])
         db.session.commit()
 
-    def mask_exporter(self, export_dir: str, type: str = "gray"):
+    def mask_exporter(self, export_dir: str):
         """Export semantic segmentation dataset in mask format
 
         Args:
             export_dir (str): The folder to export to.
-            type (str, optional): Mask type, "gray" or "pesudo". Defaults to "gray".
         """
 
         # 1. set params
         project = self.project
+        other_settings = project._get_other_settings()
+        mask_type = other_settings.get("segMaskType", "grayscale")
 
         export_data_dir = osp.join(export_dir, "JPEGImages")
         export_label_dir = osp.join(export_dir, "Annotations")
@@ -508,49 +594,8 @@ class SemanticSegmentation(InstanceSegmentation):
             export_label_path = osp.join(export_label_dir, osp.basename(data_path).split(".")[0] + ".png")
 
             copy(data_path, export_data_dir)
-            height, width = map(int, data.size.split(",")[1:3])
-            if type == "pesudo":
-                mask = np.zeros((height, width, 3))
-            else:
-                mask = np.zeros((height, width))
-
-            for ann in task.annotations:
-                # TODO: remove
-                if ann.result[:2] == "[[":
-                    continue
-
-                label_id = ann.label.id
-                result = ann.result.strip().split(",")
-                try:
-                    result = [int(float(p)) for p in result]
-                except:
-                    print(result, "to float error, plz open an issue for this")
-                if ann.type == "brush":
-                    points = result[2:]
-                    line_width = result[0]
-                    prev_w, prev_h = points[0:2]
-                else:
-                    for idx in range(0, len(result), 2):
-                        result[idx] = int(result[idx] + width / 2)
-                        result[idx + 1] = int(result[idx + 1] + height / 2)
-                    points = polygon2points(result)
-                    points = np.array(points).reshape((-1))
-                    line_width = 1
-                    prev_w, prev_h = points[0:2]
-                try:
-                    for idx in range(2, len(points), 2):
-                        w, h = points[idx : idx + 2]
-                        if type == "pesudo":
-                            color = hex_to_rgb(ann.label.color)[::-1]
-                        else:
-                            color = int(label_id)
-                        if line_width == 0:
-                            line_width = 1
-                        cv2.line(mask, (prev_w, prev_h), (w, h), color, line_width)
-                        prev_w, prev_h = w, h
-                except Exception as e:
-                    abort(detail=e.msg, status=500, title="cv2 error")
 
+            mask = draw_mask(data, mask_type=mask_type)
             cv2.imwrite(export_label_path, mask)
 
             export_data_paths.append([export_data_path])
@@ -567,11 +612,13 @@ class SemanticSegmentation(InstanceSegmentation):
         self.export_labels(export_dir, bg)
 
 
-"""
-{
-            "id": 2,
-            "name": "toy",
-            "color": "#64F3BE",
-            "supercategory": "none"
-        },
-"""
+# [INFO]base.347: = Adding label ['toy'] =
+# [1, 435, 486, 3]
+# [INFO]base.157: = JPEGImages/1.jpeg with 0 annotation(s) imported to set 1 =
+# [1, 569, 640, 3]
+# [INFO]base.157: = JPEGImages/2.jpeg with 0 annotation(s) imported to set 0 =
+# [1, 736, 1100, 3]
+# [INFO]base.157: = JPEGImages/3.jpeg with 0 annotation(s) imported to set 0 =
+# [1, 500, 500, 3]
+# [INFO]base.157: = JPEGImages/4.jpeg with 0 annotation(s) imported to set 2 =
+# 172.17.0.1 - - [09/Aug/2022 19:57:07] "POST /api/projects HTTP/1.1" 201 -
